@@ -1,6 +1,6 @@
 /*
     fileio
-    copyright (c) 1998-2011 Kazuki Iwamoto http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2013 Kazuki Iwamoto http://www.maid.org/ iwm@maid.org
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -19,25 +19,10 @@
 #define __FILEIO_H__
 
 
-#include "gcommon.h"
-#ifdef HAVE_FCNTL_H
-# include <fcntl.h>
-#endif /* HAVE_FCNTL_H */
-#ifdef HAVE_SYS_FILE_H
-# include <sys/file.h>
-#endif /* HAVE_SYS_FILE_H */
-#ifdef HAVE_SYS_STAT_H
-# include <sys/stat.h>
-#endif /* HAVE_SYS_STAT_H */
-#ifdef HAVE_SYS_TYPES_H
-# include <sys/types.h>
-#endif /* HAVE_SYS_TYPES_H */
-#ifdef HAVE_UNISTD_H
-# include <unistd.h>
-#endif /* HAVE_UNISTD_H */
+#include "gcommon/gcommon.h"
 #ifdef G_OS_WIN32
-# include <tchar.h>
 # include <windows.h>
+# include <tchar.h>
 #endif /* G_OS_WIN32 */
 
 
@@ -92,36 +77,6 @@ typedef struct _FileIOSysTime
 } FileIOSysTime;
 
 
-
-/******************************************************************************
-*                                                                             *
-* ja:ファイル名関数群                                                         *
-*                                                                             *
-******************************************************************************/
-/*  ja:ファイルのフルパスを取得する
-    file,ファイル名
-     RET,フルパス                                                           */
-#define fileio_get_full_path(file) fileio_get_absolute_path(file,NULL)
-
-
-/*  ja:ファイルの絶対パスを取得する
-    file,ファイル名
-    path,パス名
-     RET,フルパス                                                           */
-gchar *
-fileio_get_absolute_path (const gchar *file,
-                          const gchar *path);
-
-
-/*  ja:ファイルの相対パスを取得する
-    file,ファイル名(終点)
-    path,パス名(起点)
-     RET,フルパス                                                           */
-gchar *
-fileio_get_relative_path (const gchar *file,
-                          const gchar *path);
-
-
 /******************************************************************************
 *                                                                             *
 * ja:低レベルファイル入出力関数群                                             *
