@@ -1,6 +1,6 @@
 /*
     misc
-    copyright (c) 1998-2011 Kazuki Iwamoto http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2013 Kazuki Iwamoto http://www.maid.org/ iwm@maid.org
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -19,181 +19,12 @@
 #define __MISC_H__
 
 
-#include "gcommon.h"
+#include "gcommon/gcommon.h"
 
 
 G_BEGIN_DECLS
 
 
-#define MISC_CREATE_MENU_BAR       1
-#define MISC_CREATE_MENU_SHELL     2
-#define MISC_CREATE_MENU_SEPARATOR 3
-#define MISC_CREATE_MENU_STOCK     4
-#define MISC_CREATE_MENU_ITEM      5
-#define MISC_CREATE_MENU_CHECK     6
-#define MISC_CREATE_MENU_RADIO     7
-#define MISC_CREATE_MENU_TERMINAL  0
-#define MISC_CREATE_MENU_ELLIPSIS  8
-#define MISC_CREATE_MENU_NOIMAGE   16
-#define MISC_CREATE_MENU_DISABLE   32
-#define MISC_CREATE_MENU_MASK      7
-
-
-typedef struct _MiscCreateMenuEntry
-{
-  gchar *path;
-  gchar *name;
-  gchar *accel;
-  const gchar **xpm;
-  guint menu_type;
-  void (*func) (GtkWidget *widget, gpointer user_data);
-  gpointer user_data;
-  GtkWidget *widget;
-} MiscCreateMenuEntry;
-typedef struct _MiscCreateToolbarEntry
-{
-  gchar *path;
-  gchar *name;
-  const gchar **xpm;
-  void (*func) (GtkWidget *widget, gpointer user_data);
-  gpointer user_data;
-  GtkToolItem *tool_item;
-} MiscCreateToolbarEntry;
-
-
-/******************************************************************************
-*                                                                             *
-* ja:メニュー/ツールバー関数群                                                *
-*                                                                             *
-******************************************************************************/
-/*  ja:メニューを作成する
-        entries,メニュー構造体
-    accel_group,アクセルグループ                                            */
-void
-misc_create_menu (MiscCreateMenuEntry *entries,
-                  GtkAccelGroup       *accel_group);
-
-
-/*  ja:メニューを検索する
-    entries,メニュー構造体
-       path,パス
-        RET,メニューアイテム                                                */
-GtkWidget *
-misc_find_menu (MiscCreateMenuEntry *entries,
-                const gchar         *path);
-
-
-/*  ja:ツールバーを作成する
-    entries,ツールバー構造体
-        RET,ツールバー                                                      */
-GtkWidget *
-misc_create_toolbar (MiscCreateToolbarEntry *entries);
-
-
-/*  ja:ツールバーを検索する
-    entries,ツールバー構造体
-       path,パス
-        RET,ツールアイテム                                                  */
-GtkToolItem *
-misc_find_toolbar (MiscCreateToolbarEntry *entries,
-                   const gchar            *path);
-
-
-/******************************************************************************
-*                                                                             *
-* ja:特定ファイル関数群                                                       *
-*                                                                             *
-******************************************************************************/
-/*  ja:ユーザ設定ファイルを取得する
-    group,グループ
-     name,アプリケーション名
-     file,ファイル名
-      RET,ユーザ設定ファイル                                                */
-const gchar *
-misc_spec_config (const gchar *group,
-                  const gchar *name,
-                  const gchar *file);
-
-
-/*  ja:ロケールのディレクトリを取得する
-    prgname,プログラム
-        RET,ロケールのディレクトリ                                          */
-const gchar *
-misc_spec_locale (const gchar *prgname);
-
-
-/******************************************************************************
-*                                                                             *
-* ja:クローズボタン関数群                                                     *
-*                                                                             *
-******************************************************************************/
-/*  ja:クローズボタンのイメージを取得する
-    RET,イメージ,NULL:エラー                                                */
-GtkWidget *
-misc_close_image (void);
-
-
-/*  ja:クローズボタンを取得する
-    RET,ボタン,NULL:エラー                                                  */
-GtkWidget *
-misc_close_button (void);
-
-
-/******************************************************************************
-*                                                                             *
-* ja:低レベル関数群                                                           *
-*                                                                             *
-******************************************************************************/
-/*  ja:mnemonicをテキストに変換する
-    mnemonic,mnemonic
-         RET,テキスト                                                       */
-gchar *
-misc_mnemonic_to_text (const gchar *mnemonic);
-
-
-/*  ja:スクロールバーを設定する
-       scroll,スクロールウイジット
-         func,シグナル関数
-    func_data,データ
-          min,最小値
-          max,最大値
-         page,ページ
-          pos,位置                                                          */
-void
-misc_set_scroll_bar (GtkWidget  *scroll,
-                     GCallback   func,
-                     gpointer    func_data,
-                     const gint  min,
-                     const gint  max,
-                     const gint  page,
-                     const gint  pos);
-
-
-/*  ja:Windowの内容をスクロールする
-    widget,ウイジット
-        dx,X軸方向の移動
-        dy,Y軸方向の移動
-         x,スクロールする範囲の右上X座標
-         y,スクロールする範囲の右上Y座標
-     width,スクロールする範囲の幅
-    height,スクロールする範囲の高さ                                         */
-void
-misc_scroll_window (GtkWidget  *widget,
-                    const gint  dx,
-                    const gint  dy,
-                    const gint  x,
-                    const gint  y,
-                    const gint  width,
-                    const gint  height);
-
-
-/* ja:ESCが押されたとき */
-gboolean
-misc_dialog_key_press (GtkWidget   *widget,
-                       GdkEventKey *event,
-                       gpointer     user_data);
-
-
 /******************************************************************************
 *                                                                             *
 * ja:数値文字列関数群                                                         *
@@ -277,6 +108,254 @@ misc_str_to_array (gsize          *size,
                    const gboolean  flag);
 
 
+/******************************************************************************
+*                                                                             *
+* ja:特定ファイル関数群                                                       *
+*                                                                             *
+******************************************************************************/
+/*  ja:ユーザ設定ファイルを取得する
+    group,グループ
+     name,アプリケーション名
+     file,ファイル名
+      RET,ユーザ設定ファイル                                                */
+gchar *
+misc_spec_config (const gchar *group,
+                  const gchar *name,
+                  const gchar *file);
+
+
+/*  ja:ロケールのディレクトリを取得する
+    prgname,プログラム
+        RET,ロケールのディレクトリ                                          */
+gchar *
+misc_spec_locale (const gchar *prgname);
+
+
+/******************************************************************************
+*                                                                             *
+* ja:日時文字列関数群                                                         *
+*                                                                             *
+******************************************************************************/
+/*  ja:日時文字列→日時
+    cymdhms,[[CC]YY]MMDDhhmm[.ss]文字列,接尾辞YMwDhmsの数値
+        RET,日時                                                            */
+GDateTime *
+misc_string_to_time (const gchar *cymdhms);
+
+
+/*  ja:日時文字列→日時
+    datetime,基準となる日時(NULL:現在時刻)
+     cymdhms,[[CC]YY]MMDDhhmm[.ss]文字列,接尾辞YMwDhmsの数値
+         RET,日時                                                           */
+GDateTime *
+misc_string_to_time_datetime (GDateTime   *datetime,
+                              const gchar *cymdhms);
+
+
+/*  ja:日時文字列→日時
+    datetime,基準となる日時(NULL:現在時刻)
+     cymdhms,[[CC]YY]MMDDhhmm[.ss]文字列,接尾辞YMwDhmsの数値
+        sign,デフォルトの符号,NULL:+
+         RET,日時                                                           */
+GDateTime *
+misc_string_to_time_full (GDateTime   *datetime,
+                          const gchar *cymdhms,
+                          const gchar  sign);
+
+
+/*  ja:日時文字列→日時
+    cymdhms,[[CC]YY]MMDDhhmm[.ss]文字列,接尾辞YMwDhmsの数値
+       sign,デフォルトの符号,NULL:+
+        RET,日時                                                            */
+GDateTime *
+misc_string_to_time_sign (const gchar *cymdhms,
+                          const gchar  sign);
+
+
+/*  ja:日時文字列→UNIX時間
+    cymdhms,[[CC]YY]MMDDhhmm[.ss]文字列,接尾辞YMwDhmsの数値
+        RET,日時                                                            */
+gint64
+misc_string_to_epoch (const gchar *cymdhms);
+
+
+/*  ja:日時文字列→UNIX時間
+    datetime,基準となる日時(NULL:現在時刻)
+     cymdhms,[[CC]YY]MMDDhhmm[.ss]文字列,接尾辞YMwDhmsの数値
+         RET,日時                                                           */
+gint64
+misc_string_to_epoch_datetime (GDateTime   *datetime,
+                               const gchar *cymdhms);
+
+
+/*  ja:日時文字列→UNIX時間
+    datetime,基準となる日時(NULL:現在時刻)
+     cymdhms,[[CC]YY]MMDDhhmm[.ss]文字列,接尾辞YMwDhmsの数値
+        sign,デフォルトの符号,NULL:+
+         RET,日時                                                           */
+gint64
+misc_string_to_epoch_full (GDateTime   *datetime,
+                           const gchar *cymdhms,
+                           const gchar  sign);
+
+
+/*  ja:日時文字列→UNIX時間
+    cymdhms,[[CC]YY]MMDDhhmm[.ss]文字列,接尾辞YMwDhmsの数値
+       sign,デフォルトの符号,NULL:+
+        RET,日時                                                            */
+gint64
+misc_string_to_epoch_sign (const gchar *cymdhms,
+                           const gchar  sign);
+
+
+#ifndef USE_GTK_EMULATE
+/******************************************************************************
+*                                                                             *
+* ja:メニュー/ツールバー関数群                                                *
+*                                                                             *
+******************************************************************************/
+#define MISC_CREATE_MENU_BAR       1
+#define MISC_CREATE_MENU_SHELL     2
+#define MISC_CREATE_MENU_SEPARATOR 3
+#define MISC_CREATE_MENU_STOCK     4
+#define MISC_CREATE_MENU_ITEM      5
+#define MISC_CREATE_MENU_CHECK     6
+#define MISC_CREATE_MENU_RADIO     7
+#define MISC_CREATE_MENU_TERMINAL  0
+#define MISC_CREATE_MENU_ELLIPSIS  8
+#define MISC_CREATE_MENU_NOIMAGE   16
+#define MISC_CREATE_MENU_DISABLE   32
+#define MISC_CREATE_MENU_MASK      7
+
+
+typedef struct _MiscCreateMenuEntry
+{
+  gchar *path;
+  gchar *name;
+  gchar *accel;
+  const gchar **xpm;
+  guint menu_type;
+  void (*func) (GtkWidget *widget, gpointer user_data);
+  gpointer user_data;
+  GtkWidget *widget;
+} MiscCreateMenuEntry;
+typedef struct _MiscCreateToolbarEntry
+{
+  gchar *path;
+  gchar *name;
+  const gchar **xpm;
+  void (*func) (GtkWidget *widget, gpointer user_data);
+  gpointer user_data;
+  GtkToolItem *tool_item;
+} MiscCreateToolbarEntry;
+
+
+/*  ja:メニューを作成する
+        entries,メニュー構造体
+    accel_group,アクセルグループ                                            */
+void
+misc_create_menu (MiscCreateMenuEntry *entries,
+                  GtkAccelGroup       *accel_group);
+
+
+/*  ja:メニューを検索する
+    entries,メニュー構造体
+       path,パス
+        RET,メニューアイテム                                                */
+GtkWidget *
+misc_find_menu (MiscCreateMenuEntry *entries,
+                const gchar         *path);
+
+
+/*  ja:ツールバーを作成する
+    entries,ツールバー構造体
+        RET,ツールバー                                                      */
+GtkWidget *
+misc_create_toolbar (MiscCreateToolbarEntry *entries);
+
+
+/*  ja:ツールバーを検索する
+    entries,ツールバー構造体
+       path,パス
+        RET,ツールアイテム                                                  */
+GtkToolItem *
+misc_find_toolbar (MiscCreateToolbarEntry *entries,
+                   const gchar            *path);
+
+
+/******************************************************************************
+*                                                                             *
+* ja:クローズボタン関数群                                                     *
+*                                                                             *
+******************************************************************************/
+/*  ja:クローズボタンのイメージを取得する
+    RET,イメージ,NULL:エラー                                                */
+GtkWidget *
+misc_close_image (void);
+
+
+/*  ja:クローズボタンを取得する
+    RET,ボタン,NULL:エラー                                                  */
+GtkWidget *
+misc_close_button (void);
+
+
+/******************************************************************************
+*                                                                             *
+* ja:低レベル関数群                                                           *
+*                                                                             *
+******************************************************************************/
+/*  ja:mnemonicをテキストに変換する
+    mnemonic,mnemonic
+         RET,テキスト                                                       */
+gchar *
+misc_mnemonic_to_text (const gchar *mnemonic);
+
+
+/*  ja:スクロールバーを設定する
+       scroll,スクロールウイジット
+         func,シグナル関数
+    func_data,データ
+          min,最小値
+          max,最大値
+         page,ページ
+          pos,位置                                                          */
+void
+misc_set_scroll_bar (GtkWidget  *scroll,
+                     GCallback   func,
+                     gpointer    func_data,
+                     const gint  min,
+                     const gint  max,
+                     const gint  page,
+                     const gint  pos);
+
+
+/*  ja:Windowの内容をスクロールする
+    widget,ウイジット
+        dx,X軸方向の移動
+        dy,Y軸方向の移動
+         x,スクロールする範囲の右上X座標
+         y,スクロールする範囲の右上Y座標
+     width,スクロールする範囲の幅
+    height,スクロールする範囲の高さ                                         */
+void
+misc_scroll_window (GtkWidget  *widget,
+                    const gint  dx,
+                    const gint  dy,
+                    const gint  x,
+                    const gint  y,
+                    const gint  width,
+                    const gint  height);
+
+
+/* ja:ESCが押されたとき */
+gboolean
+misc_dialog_key_press (GtkWidget   *widget,
+                       GdkEventKey *event,
+                       gpointer     user_data);
+#endif /* not USE_GTK_EMULATE */
+
+
 G_END_DECLS
 
 
