@@ -1,6 +1,6 @@
 /*
     orzcharset
-    copyright (c) 1998-2010 Kazuki Iwamoto http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2013 Kazuki Iwamoto http://www.maid.org/ iwm@maid.org
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -19,7 +19,7 @@
 #define __ORZ_CHARSET_H__
 
 
-#include "misc/gcommon.h"
+#include "gcommon/gcommon.h"
 #include "misc/charuty.h"
 
 
@@ -40,7 +40,9 @@ typedef struct _OrzCharsetClass OrzCharsetClass;
 struct _OrzCharset
 {
   /*< private >*/
-#if GTK_CHECK_VERSION(2,4,0)
+#if GTK_CHECK_VERSION(2,24,0)
+  GtkComboBoxText parent_instance;
+#elif GTK_CHECK_VERSION(2,4,0)
   GtkComboBoxEntry parent_instance;
 #else /* not GTK_CHECK_VERSION(2,4,0) */
   GtkCombo parent_instance;
@@ -51,7 +53,9 @@ struct _OrzCharset
 
 struct _OrzCharsetClass
 {
-#if GTK_CHECK_VERSION(2,4,0)
+#if GTK_CHECK_VERSION(2,24,0)
+  GtkComboBoxTextClass parent_class;
+#elif GTK_CHECK_VERSION(2,4,0)
   GtkComboBoxEntryClass parent_class;
 #else /* not GTK_CHECK_VERSION(2,4,0) */
   GtkComboClass parent_class;
