@@ -1,6 +1,6 @@
 /*
     orzmdi
-    copyright (c) 1998-2011 Kazuki Iwamoto http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2013 Kazuki Iwamoto http://www.maid.org/ iwm@maid.org
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -256,11 +256,11 @@ orz_mdi_remove (GtkContainer *container,
 
 static void
 orz_mdi_switch_page (GtkNotebook     *notebook,
-#if GTK_CHECK_VERSION(2,22,0)
-                     gpointer         page,
-#else /* not GTK_CHECK_VERSION(2,22,0) */
+#if GTK_CHECK_VERSION(3,0,0)
+                     GtkWidget       *page,
+#else /* not GTK_CHECK_VERSION(3,0,0) */
                      GtkNotebookPage *page,
-#endif /* not GTK_CHECK_VERSION(2,22,0) */
+#endif /* not GTK_CHECK_VERSION(3,0,0) */
                      guint            page_num)
 {
   GtkWidget *child;
@@ -578,8 +578,8 @@ orz_mdi_insert_page (OrzMdi         *mdi,
   tab = g_malloc0 (sizeof (OrzMdiTab));
   tab->page_data = page_data;
   tab->created = created;
-  tab->file = file ? created ? g_strdup (file) : fileio_get_full_path (file)
-                                                            : g_strdup ("");
+  tab->file = file ? created ? g_strdup (file)
+                            : g_path_get_absolute (file, NULL) : g_strdup ("");
   tab->same = -2;
   tab->mdi = mdi;
   tab->child = child;
@@ -608,12 +608,13 @@ orz_mdi_insert_page (OrzMdi         *mdi,
   gtk_widget_show (hbox);
   /* ja:ツールチップス */
   event = gtk_event_box_new ();
-#if GLIB_CHECK_VERSION(2,4,0)
+#if GTK_CHECK_VERSION(2,4,0)
   gtk_event_box_set_visible_window (GTK_EVENT_BOX (event), FALSE);
-#endif /* GLIB_CHECK_VERSION(2,4,0) */
+#endif /* GTK_CHECK_VERSION(2,4,0) */
   gtk_container_add (GTK_CONTAINER (event), hbox);
 #if GTK_CHECK_VERSION(2,12,0)
   gtk_widget_set_has_tooltip (event, TRUE);
+  gtk_widget_set_tooltip_text (event, tab->file);
 #else /* not GTK_CHECK_VERSION(2,12,0) */
   gtk_tooltips_set_tip (mdi->tooltips, event, tab->file, tab->file);
 #endif /* not GTK_CHECK_VERSION(2,12,0) */
@@ -808,7 +809,7 @@ orz_mdi_set_file (OrzMdi      *mdi,
                   file_remove_edit (mdi, tab, file);
                   g_free (tab->file);
                   tab->file = tab->created ? g_strdup (file)
-                                           : fileio_get_full_path (file);
+                                           : g_path_get_absolute (file, NULL);
                   tab->same = -2;
                   file_add_edit (mdi, tab);
                   orz_mdi_label_markup (tab);
