@@ -1,6 +1,6 @@
 /*
     Text maid
-    copyright (c) 1998-2011 Kazuki Iwamoto http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2013 Kazuki Iwamoto http://www.maid.org/ iwm@maid.org
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -32,15 +32,14 @@
 #include "sigfile.h"
 #include "valchr.h"
 #include "version.h"
-#include "misc/fileio.h"
 #include "misc/misc.h"
 #include "orz/orzhistory.h"
 #include "orz/orzmdi.h"
 #include "orz/orzpref.h"
 #ifdef G_OS_WIN32
 # include <gdk/gdkwin32.h>
-# include <tchar.h>
 # include <windows.h>
+# include <tchar.h>
 #endif /* G_OS_WIN32 */
 
 
@@ -274,7 +273,7 @@ command_open (GtkWidget *widget,
   if (file)
     {
       g_free (open_path);
-      path = fileio_get_full_path (file);
+      path = g_path_get_absolute (file, NULL);
       open_path = g_path_get_dirname (path);
       g_free (path);
       file_open_edit (file);
@@ -566,7 +565,7 @@ command_saveas (GtkWidget *widget,
       if (result && file_save_text (file, tmaid))
         {
           g_free (save_path);
-          path = fileio_get_full_path (file);
+          path = g_path_get_absolute (file, NULL);
           save_path = g_path_get_dirname (path);
           g_free (path);
           /* ja:諸設定 */
