@@ -1,6 +1,6 @@
 /*
     Text maid
-    copyright (c) 1998-2011 Kazuki Iwamoto http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2013 Kazuki Iwamoto http://www.maid.org/ iwm@maid.org
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -651,8 +651,7 @@ edit_put_mem (TmaidWindow *tmaid,
     {
       /* ja:挿入位置以降の文字列をバッファに保存する */
       temp_leng = p->length - data_pos;
-      temp = g_malloc (temp_leng * sizeof (gchar));
-      g_memmove (temp, p->text + data_pos, temp_leng * sizeof (gchar));
+      temp = g_memdup (p->text + data_pos, temp_leng * sizeof (gchar));
       p->length = data_pos;
     }
   else
