@@ -1,6 +1,6 @@
 /*
     Text maid
-    copyright (c) 1998-2012 Kazuki Iwamoto http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2013 Kazuki Iwamoto http://www.maid.org/ iwm@maid.org
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -174,19 +174,20 @@ file_open_text (const gchar *file,
     }
   g_strfreev (charset);
   /* ja:改行コード判定 */
-  if (tmaid->ft.crlf >= 3)
+  if (tmaid->ft.negotiate)
     {
       gint crlf[3];
 
-      crlf[0] = crlf[1] = crlf[2] = 0;
+      for (i = 0; i < 3; i++)
+        crlf[i] = 0;
       i = 0;
       while (abort_break && i < length)
         if (i <= length - 2 && outbuf[i] == '\r' && outbuf[i + 1] == '\n')
           {
-            i += 2;
             crlf[0]++;
+            i += 2;
           }
-        else 
+        else
           {
             if (outbuf[i] == '\r')
               crlf[1]++;
@@ -194,6 +195,9 @@ file_open_text (const gchar *file,
               crlf[2]++;
             i++;
           }
+      for (i = 0; i < 3; i++)
+        crlf[i] *= 2;
+      crlf[tmaid->ft.crlf]++;
 #ifdef G_OS_WIN32
       if (crlf[0] >= crlf[1] && crlf[0] >= crlf[2])
         tmaid->ft.crlf = 0;
@@ -234,8 +238,7 @@ file_open_text (const gchar *file,
                 break;
         }
       p->length = j - i;
-      p->text = g_malloc (p->length * sizeof (gchar));
-      g_memmove (p->text, outbuf + i, p->length);
+      p->text = g_memdup (outbuf + i, p->length * sizeof (gchar));
       if (j < length)
         {
           LineBuffer *q;
@@ -371,7 +374,7 @@ file_open_edit (const gchar *file)
     {
       gchar *name, *text;
 
-      filename = fileio_get_full_path (file);
+      filename = g_path_get_absolute (file, NULL);
       name = g_path_get_basename (file);
       text = g_filename_to_utf8 (name, -1, NULL, NULL, NULL);
       g_free (name);
