@@ -1,6 +1,6 @@
 /*
     Text maid
-    copyright (c) 1998-2008 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2011 Kazuki Iwamoto http://www.maid.org/ iwm@maid.org
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -36,12 +36,14 @@ jump_operation (TmaidWindow *tmaid,
 {
   gint sx, sy;
   GdkPoint cursor, select, top;
+  GtkAllocation allocation;
 
   cursor = tmaid->cursor;
   select = tmaid->select;
   top = tmaid->top;
-  sx = MAX( tmaid->drawing->allocation.width / tmaid->font_width, 1);
-  sy = MAX (tmaid->drawing->allocation.height / tmaid->font_height, 1);
+  gtk_widget_get_allocation (tmaid->drawing, &allocation);
+  sx = MAX( allocation.width / tmaid->font_width, 1);
+  sy = MAX (allocation.height / tmaid->font_height, 1);
   tmaid->cursor.y = line < 0 ? tmaid->max + line : line - 1;
   if (tmaid->cursor.y < 0)
     tmaid->cursor.y = 0;
@@ -159,10 +161,9 @@ jump_dialog (JumpConfig *jmpcfg)
                                     G_CALLBACK (jump_dialog_changed), dialog);
   gtk_editable_select_region (GTK_EDITABLE (entry), 0, -1);
   /* ja:フレームとボックス */
-  vbox = gtk_vbox_new (FALSE, SPACING);
-  gtk_container_set_border_width (GTK_CONTAINER (vbox), SPACING);
+  vbox = gtk_dialog_get_content_area (GTK_DIALOG (dialog));
+  gtk_box_set_spacing (GTK_BOX (vbox), SPACING);
   gtk_box_pack_start (GTK_BOX (vbox), entry, TRUE, TRUE, 0);
-  gtk_container_add (GTK_CONTAINER (GTK_DIALOG (dialog)->vbox), vbox);
 
   gtk_dialog_set_response_sensitive (GTK_DIALOG (dialog),
                                                     GTK_RESPONSE_OK, FALSE);
