@@ -1,6 +1,6 @@
 /*
     Text maid
-    copyright (c) 1998-2011 Kazuki Iwamoto http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2013 Kazuki Iwamoto http://www.maid.org/ iwm@maid.org
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -179,6 +179,8 @@ keyfile_read (const gchar *file)
           ftype[i].tab = g_key_file_get_integer (key_file, group, "tab", NULL);
           ftype[i].writemode = g_key_file_get_integer (key_file,
                                                     group, "writemode", NULL);
+          ftype[i].negotiate = g_key_file_get_boolean (key_file,
+                                                    group, "negotiate", NULL);
           ftype[i].associate = g_key_file_get_boolean (key_file,
                                                     group, "associate", NULL);
           ftype[i].autoindent = g_key_file_get_boolean (key_file,
@@ -211,6 +213,15 @@ keyfile_read (const gchar *file)
                                                     group, "uline", NULL);
           ftype[i].vline = g_key_file_get_boolean (key_file, 
                                                     group, "vline", NULL);
+          if (ftype[i].crlf > 2)
+            {
+#ifdef G_OS_WIN32
+              ftype[i].crlf = 0;
+#else /* not G_OS_WIN32 */
+              ftype[i].crlf = 2;
+#endif /* not G_OS_WIN32 */
+              ftype[i].negotiate = TRUE;
+            }
           /* ja:キャラクターセット */
           ftype[i].charset = g_key_file_get_string (key_file,
                                                     group, "charset", NULL);
@@ -282,9 +293,14 @@ keyfile_read (const gchar *file)
       ftype = g_malloc0 (ftnum * sizeof (FileType));
       ftype[0].text = g_strdup (_("All Files"));
       ftype[0].ext = g_strdup ("*");
-      ftype[0].crlf = 3;
+#ifdef G_OS_WIN32
+      ftype[0].crlf = 0;
+#else /* not G_OS_WIN32 */
+      ftype[0].crlf = 2;
+#endif /* not G_OS_WIN32 */
       ftype[0].margin = 80;
       ftype[0].tab = 8;
+      ftype[0].negotiate = TRUE;
       ftype[0].associate = TRUE;
       ftype[0].syscol = TRUE;
       /* ja:キャラクターセット */
@@ -434,6 +450,8 @@ keyfile_write (const gchar *file)
           g_key_file_set_integer (key_file, group, "tab", ftype[i].tab);
           g_key_file_set_integer (key_file, group, "writemode",
                                                         ftype[i].writemode);
+          g_key_file_set_boolean (key_file, group, "negotiate",
+                                                        ftype[i].negotiate);
           g_key_file_set_boolean (key_file, group, "associate",
                                                         ftype[i].associate);
           g_key_file_set_boolean (key_file, group, "autoindent",
