@@ -1,6 +1,6 @@
 /*
     Text maid
-    copyright (c) 1998-2008 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2011 Kazuki Iwamoto http://www.maid.org/ iwm@maid.org
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -22,7 +22,6 @@
 #include "replace.h"
 #include "misc/misc.h"
 #include "orz/orzmdi.h"
-#include <gdk/gdkkeysyms.h>
 
 
 GtkWidget *find_box = NULL;
@@ -61,7 +60,19 @@ find_box_get_contents (void)
   for (i = 0; i < FIND_TEXT - 1 && find_text[i]; i++)
     if (g_strcmp (find_text[i], text) == 0)
       break;
-#if GTK_CHECK_VERSION(2,4,0)
+#if GTK_CHECK_VERSION(2,24,0)
+  if (find_text[i])
+    {
+      GtkListStore *store;
+      GtkTreeIter iter;
+
+      store = GTK_LIST_STORE
+                        (gtk_combo_box_get_model (GTK_COMBO_BOX (find_combo)));
+      gtk_tree_model_iter_nth_child (GTK_TREE_MODEL (store), &iter, NULL, i);
+      gtk_list_store_remove (store, &iter);
+    }
+  gtk_combo_box_text_prepend_text (GTK_COMBO_BOX_TEXT (find_combo), text);
+#elif GTK_CHECK_VERSION(2,4,0)
   if (find_text[i])
     gtk_combo_box_remove_text (GTK_COMBO_BOX (find_combo), i);
   gtk_combo_box_prepend_text (GTK_COMBO_BOX (find_combo), text);
@@ -78,13 +89,27 @@ find_box_get_contents (void)
       g_list_free (glist);
     }
 #endif /* not GTK_CHECK_VERSION(2,4,0) */
-  if (GTK_WIDGET_VISIBLE (replace_combo))
+  if (gtk_widget_get_visible (replace_combo))
     {
       text = gtk_entry_get_text (GTK_ENTRY (replace_entry));
       for (i = 0; i < REPLACE_TEXT - 1 && replace_text[i]; i++)
         if (g_strcmp (replace_text[i], text) == 0)
           break;
-#if GTK_CHECK_VERSION(2,4,0)
+#if GTK_CHECK_VERSION(2,24,0)
+      if (replace_text[i])
+        {
+          GtkListStore *store;
+          GtkTreeIter iter;
+
+          store = GTK_LIST_STORE
+                    (gtk_combo_box_get_model (GTK_COMBO_BOX (replace_combo)));
+          gtk_tree_model_iter_nth_child (GTK_TREE_MODEL (store),
+                                                            &iter, NULL, i);
+          gtk_list_store_remove (store, &iter);
+        }
+      gtk_combo_box_text_prepend_text (GTK_COMBO_BOX_TEXT (replace_combo),
+                                                                        text);
+#elif GTK_CHECK_VERSION(2,4,0)
       if (replace_text[i])
         gtk_combo_box_remove_text (GTK_COMBO_BOX (replace_combo), i);
       gtk_combo_box_prepend_text (GTK_COMBO_BOX (replace_combo), text);
@@ -141,7 +166,7 @@ find_box_activate (GtkWidget *widget,
                    gpointer   user_data)
 {
   if (g_strlen (gtk_entry_get_text (GTK_ENTRY (widget))) > 0)
-    gtk_button_clicked (GTK_WIDGET_VISIBLE (find_button)
+    gtk_button_clicked (gtk_widget_get_visible (find_button)
                     ? GTK_BUTTON (find_button) : GTK_BUTTON (replace_button0));
 }
 
@@ -166,7 +191,7 @@ find_key_press (GtkWidget   *widget,
                 GdkEventKey *event,
                 gpointer     user_data)
 {
-  if (event->keyval == GDK_Escape)
+  if (event->keyval == GDK_KEY_Escape)
     find_box_end ();
   return FALSE;
 }
@@ -210,9 +235,16 @@ find_box_get_widget (void)
                                                             find_ignorecase);
       /* ja:コンボボックス */
 #if GTK_CHECK_VERSION(2,4,0)
+# if GTK_CHECK_VERSION(2,24,0)
+      find_combo = gtk_combo_box_text_new_with_entry ();
+      for (i = 0; i < FIND_TEXT && find_text[i]; i++)
+        gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (find_combo),
+                                                                find_text[i]);
+# else /* not GTK_CHECK_VERSION(2,24,0) */
       find_combo = gtk_combo_box_entry_new_text ();
       for (i = 0; i < FIND_TEXT && find_text[i]; i++)
         gtk_combo_box_append_text (GTK_COMBO_BOX (find_combo), find_text[i]);
+# endif /* not GTK_CHECK_VERSION(2,24,0) */
       if (find_text[0])
         gtk_combo_box_set_active (GTK_COMBO_BOX (find_combo), 0);
       find_entry = gtk_bin_get_child (GTK_BIN (find_combo));
@@ -235,10 +267,17 @@ find_box_get_widget (void)
       g_signal_connect (G_OBJECT (find_entry), "changed",
                                         G_CALLBACK (find_box_changed), NULL);
 #if GTK_CHECK_VERSION(2,4,0)
+# if GTK_CHECK_VERSION(2,24,0)
+      replace_combo = gtk_combo_box_text_new_with_entry ();
+      for (i = 0; i < REPLACE_TEXT && replace_text[i]; i++)
+        gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (replace_combo),
+                                                            replace_text[i]);
+# else /* not GTK_CHECK_VERSION(2,24,0) */
       replace_combo = gtk_combo_box_entry_new_text ();
       for (i = 0; i < REPLACE_TEXT && replace_text[i]; i++)
         gtk_combo_box_append_text (GTK_COMBO_BOX (replace_combo),
                                                             replace_text[i]);
+# endif /* not GTK_CHECK_VERSION(2,24,0) */
       if (replace_text[0])
         gtk_combo_box_set_active (GTK_COMBO_BOX (replace_combo), 0);
       replace_entry = gtk_bin_get_child (GTK_BIN (replace_combo));
@@ -340,7 +379,7 @@ replace_box_start (void)
   gtk_widget_show (replace_combo);
   gtk_widget_show (replace_label);
   gtk_editable_select_region (GTK_EDITABLE (replace_entry), 0, -1);
-  if (GTK_WIDGET_HAS_FOCUS (find_entry))
+  if (gtk_widget_has_focus (find_entry))
     {
       gtk_widget_grab_focus (replace_entry);
     }
