@@ -1,6 +1,6 @@
 /*
     Text maid
-    copyright (c) 1998-2011 Kazuki Iwamoto http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2013 Kazuki Iwamoto http://www.maid.org/ iwm@maid.org
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -27,9 +27,7 @@
 #  include <cairo-win32.h>
 # endif /* GTK_CHECK_VERSION(2,24,0) */
 # include <gdk/gdkwin32.h>
-#else /* not G_OS_WIN32 */
-# include "misc/fileio.h"
-#endif /* not G_OS_WIN32 */
+#endif /* G_OS_WIN32 */
 
 
 PrintConfig printer;                        /* ja:印刷の設定 */
@@ -782,7 +780,7 @@ print_dialog_clicked_file (GtkWidget   *widget,
       gchar *dir, *path;
 
       dir = g_path_get_dirname (file);
-      path = fileio_get_full_path (dir);
+      path = g_path_get_absolute (dir, NULL);
       g_free (dir);
       if (g_file_test (path, G_FILE_TEST_EXISTS))
         gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER (dialog), path);
