@@ -1,6 +1,6 @@
 /*
     Text maid
-    copyright (c) 1998-2011 Kazuki Iwamoto http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2013 Kazuki Iwamoto http://www.maid.org/ iwm@maid.org
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -46,6 +46,7 @@ property_copy (FileType *ft_dst,
   ft_dst->margin = ft_src->margin;
   ft_dst->tab = ft_src->tab;
   ft_dst->writemode = ft_src->writemode;
+  ft_dst->negotiate = ft_src->negotiate;
   ft_dst->autoindent = ft_src->autoindent;
   ft_dst->code = ft_src->code;
   ft_dst->eof = ft_src->eof;
@@ -172,9 +173,6 @@ typedef struct _PropertyDialog
   GtkWidget *check_eof;       /* ja:TRUE:1Ahをファイルの末尾に書き加える */
   GtkWidget *check_overwrite; /* ja:TRUE:ファイルを上書きするときに確認する */
   GtkWidget *check_syscol;    /* ja:TRUE:システム色を使う */
-  GtkWidget *check_html;      /* ja:TRUE:HTML数値文字参照を変換する */
-  GtkWidget *check_esc;       /* ja:TRUE:エスケープシーケンスを変換する */
-  GtkWidget *check_associate; /* ja:TRUE:関連づける */
   GtkWidget *combo;
   GtkWidget *entry_text;
   GtkWidget *entry_ext;
@@ -324,9 +322,9 @@ property_dialog_clicked_color (GtkWidget      *widget,
 }
 
 
-/* ja:文字符号化方式の設定ボタンが押された */
+/* ja:文字符号化方式の登録ボタンが押された */
 static void
-property_dialog_clicked_charlist (GtkWidget      *widget,
+property_dialog_clicked_register (GtkWidget      *widget,
                                   PropertyDialog *propdlg)
 {
   gint i;
@@ -527,15 +525,23 @@ property_dialog (GtkWindow *parent,
 #if ! GTK_CHECK_VERSION(2,4,0)
   GList *glist;
 #endif /* not GTK_CHECK_VERSION(2,4,0) */
-  GtkStockItem stock_item;
   GtkCellRenderer *renderer;
   GtkListStore *store;
-  GtkTreeIter iter;
   GtkTreeSelection *select;
   GtkTreeViewColumn *column;
-  GtkWidget *button_associated, *button_auto, *scroll, *label;
+  GtkWidget *check_html;      /* ja:TRUE:HTML数値文字参照を変換する */
+  GtkWidget *check_esc;       /* ja:TRUE:エスケープシーケンスを変換する */
+  GtkWidget *check_negotiate; /* ja:TRUE:CRLF自動判別 */
+  GtkWidget *check_associate; /* ja:TRUE:関連づける */
+  GtkWidget *button_associated, *button_register, *scroll, *label;
   GtkWidget *hbox, *tbox, *vbox;
-  GtkWidget *frame0, *frame1, *frame2, *frame3, *frame4, *frame5, *frame6;
+  GtkWidget *frame_display;
+  GtkWidget *frame_right;
+  GtkWidget *frame_tab;
+  GtkWidget *frame_edit;
+  GtkWidget *frame_save;
+  GtkWidget *frame_color;
+  GtkWidget *frame_character;
 #if ! GTK_CHECK_VERSION(2,4,0)
   GtkWidget *button_font;
 #endif /* not GTK_CHECK_VERSION(2,4,0) */
@@ -550,6 +556,8 @@ property_dialog (GtkWindow *parent,
   /* ja:メインウインドウ */
   if (!ft->text || !ft->ext)
     {
+      GtkStockItem stock_item;
+
       gtk_stock_lookup (GTK_STOCK_PROPERTIES, &stock_item);
       title = misc_mnemonic_to_text (stock_item.label);
     }
@@ -590,24 +598,18 @@ property_dialog (GtkWindow *parent,
 #endif /* not GTK_CHECK_VERSION(2,4,0) */
   if (ft->text && ft->ext)
     {
-      button_auto = gtk_button_new_with_label (_("Auto Negotiation"));
-      g_signal_connect (G_OBJECT (button_auto), "clicked",
-                    G_CALLBACK (property_dialog_clicked_charlist), &propdlg);
+      button_register = gtk_button_new_with_label (_("Register"));
+      g_signal_connect (G_OBJECT (button_register), "clicked",
+                    G_CALLBACK (property_dialog_clicked_register), &propdlg);
+      button_associated = NULL;
     }
   else
-    {
-      button_auto = NULL;
-    }
-  if (!ft->text && !ft->ext)
     {
       button_associated
                 = gtk_button_new_with_mnemonic (_("_Associated File Type"));
       g_signal_connect (G_OBJECT (button_associated), "clicked",
                         G_CALLBACK (property_dialog_clicked_ftype), &propdlg);
-    }
-  else
-    {
-      button_associated = NULL;
+      button_register = NULL;
     }
   /* ja:チェックボタン */
   propdlg.check_gline = gtk_check_button_new_with_label (_("Grid"));
@@ -683,28 +685,33 @@ property_dialog (GtkWindow *parent,
                         G_CALLBACK (property_dialog_toggled_check), &propdlg);
   if (ft->text && ft->ext)
     {
-      propdlg.check_html = gtk_check_button_new_with_label
+      check_html = gtk_check_button_new_with_label
                                     (_("HTML Numeric character reference"));
-      propdlg.check_esc = gtk_check_button_new_with_label
-                                    (_("Escape sequence"));
-      propdlg.check_associate = gtk_check_button_new_with_mnemonic
+      check_esc = gtk_check_button_new_with_label (_("Escape sequence"));
+      check_negotiate = gtk_check_button_new_with_label
+                                    (_("Auto Negotiation"));
+      check_associate = gtk_check_button_new_with_mnemonic
                                     (_("_Associate File Type"));
       gtk_toggle_button_set_active
-                (GTK_TOGGLE_BUTTON (propdlg.check_html), ft->html);
+                (GTK_TOGGLE_BUTTON (check_negotiate), ft->negotiate);
       gtk_toggle_button_set_active
-                (GTK_TOGGLE_BUTTON (propdlg.check_esc), ft->esc);
+                (GTK_TOGGLE_BUTTON (check_html), ft->html);
       gtk_toggle_button_set_active
-                (GTK_TOGGLE_BUTTON (propdlg.check_associate), ft->associate);
-      g_signal_connect (G_OBJECT (propdlg.check_html), "toggled",
+                (GTK_TOGGLE_BUTTON (check_esc), ft->esc);
+      gtk_toggle_button_set_active
+                (GTK_TOGGLE_BUTTON (check_associate), ft->associate);
+      g_signal_connect (G_OBJECT (check_negotiate), "toggled",
                         G_CALLBACK (property_dialog_ok_sensitive), &propdlg);
-      g_signal_connect (G_OBJECT (propdlg.check_esc), "toggled",
+      g_signal_connect (G_OBJECT (check_html), "toggled",
                         G_CALLBACK (property_dialog_ok_sensitive), &propdlg);
-      g_signal_connect (G_OBJECT (propdlg.check_associate), "toggled",
+      g_signal_connect (G_OBJECT (check_esc), "toggled",
+                        G_CALLBACK (property_dialog_ok_sensitive), &propdlg);
+      g_signal_connect (G_OBJECT (check_associate), "toggled",
                         G_CALLBACK (property_dialog_ok_sensitive), &propdlg);
     }
   else
     {
-      propdlg.check_html = propdlg.check_esc = propdlg.check_associate = NULL;
+      check_negotiate = check_html = check_esc = check_associate = NULL;
     }
   /* ja:コンボボックス */
 #if GTK_CHECK_VERSION(2,4,0)
@@ -713,16 +720,11 @@ property_dialog (GtkWindow *parent,
   gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (propdlg.combo), "CR+LF");
   gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (propdlg.combo), "CR");
   gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (propdlg.combo), "LF");
-  if (ft->text && ft->ext)
-    gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (propdlg.combo),
-                                                                    _("Auto"));
 # else /* not GTK_CHECK_VERSION(2,24,0) */
   propdlg.combo = gtk_combo_box_new_text ();
   gtk_combo_box_append_text (GTK_COMBO_BOX (propdlg.combo), "CR+LF");
   gtk_combo_box_append_text (GTK_COMBO_BOX (propdlg.combo), "CR");
   gtk_combo_box_append_text (GTK_COMBO_BOX (propdlg.combo), "LF");
-  if (ft->text && ft->ext)
-    gtk_combo_box_append_text (GTK_COMBO_BOX (propdlg.combo), _("Auto"));
 # endif /* not GTK_CHECK_VERSION(2,24,0) */
   gtk_combo_box_set_active (GTK_COMBO_BOX (propdlg.combo), ft->crlf);
   g_signal_connect (G_OBJECT (propdlg.combo), "changed",
@@ -731,8 +733,6 @@ property_dialog (GtkWindow *parent,
   glist = g_list_append (NULL, "CR+LF");
   glist = g_list_append (glist, "CR");
   glist = g_list_append (glist, "LF");
-  if (ft->text && ft->ext)
-    glist = g_list_append (glist, _("Auto"));
   propdlg.combo = gtk_combo_new ();
   gtk_combo_set_popdown_strings (GTK_COMBO (propdlg.combo), glist);
   gtk_entry_set_text (GTK_ENTRY (GTK_COMBO (propdlg.combo)->entry),
@@ -868,6 +868,8 @@ property_dialog (GtkWindow *parent,
     xpm[i] = "XXXXXXXXXXXXXXXXXXXXXXXX";
   for (i = 0; i < 12; i++)
     {
+      GtkTreeIter iter;
+
       xpm[1] = g_strdup_printf ("X\tc #%02X%02X%02X",
                                                     ft->color[i].red / 256,
                                                     ft->color[i].green / 256,
@@ -900,8 +902,8 @@ property_dialog (GtkWindow *parent,
   g_signal_connect (G_OBJECT (propdlg.spin_tab), "changed",
                         G_CALLBACK (property_dialog_ok_sensitive), &propdlg);
   /* ja:フレームとボックス */
-  frame0 = gtk_frame_new ("");
-  label = gtk_frame_get_label_widget (GTK_FRAME (frame0));
+  frame_display = gtk_frame_new ("");
+  label = gtk_frame_get_label_widget (GTK_FRAME (frame_display));
   gtk_label_set_text_with_mnemonic (GTK_LABEL (label), _("_Display"));
   gtk_label_set_mnemonic_widget (GTK_LABEL (label), propdlg.check_gline);
   hbox = gtk_hbox_new (FALSE, SPACING);
@@ -909,10 +911,10 @@ property_dialog (GtkWindow *parent,
   gtk_box_pack_start (GTK_BOX (hbox), propdlg.check_gline, TRUE, TRUE, 0);
   gtk_box_pack_start (GTK_BOX (hbox), propdlg.check_space, TRUE, TRUE, 0);
   gtk_box_pack_start (GTK_BOX (hbox), propdlg.check_nline, TRUE, TRUE, 0);
-  gtk_container_add (GTK_CONTAINER (frame0), hbox);
+  gtk_container_add (GTK_CONTAINER (frame_display), hbox);
 
-  frame1 = gtk_frame_new ("");
-  label = gtk_frame_get_label_widget (GTK_FRAME (frame1));
+  frame_right = gtk_frame_new ("");
+  label = gtk_frame_get_label_widget (GTK_FRAME (frame_right));
   gtk_label_set_text_with_mnemonic (GTK_LABEL (label), _("_Right Margin"));
   gtk_label_set_mnemonic_widget (GTK_LABEL (label), propdlg.spin_margin);
   hbox = gtk_hbox_new (FALSE, SPACING);
@@ -920,10 +922,10 @@ property_dialog (GtkWindow *parent,
   gtk_box_pack_start (GTK_BOX (hbox), propdlg.spin_margin, TRUE, TRUE, 0);
   gtk_box_pack_start (GTK_BOX (hbox), propdlg.check_mline, FALSE, FALSE, 0);
   gtk_box_pack_start (GTK_BOX (hbox), propdlg.check_limit, FALSE, FALSE, 0);
-  gtk_container_add (GTK_CONTAINER (frame1), hbox);
+  gtk_container_add (GTK_CONTAINER (frame_right), hbox);
 
-  frame2 = gtk_frame_new ("");
-  label = gtk_frame_get_label_widget (GTK_FRAME (frame2));
+  frame_tab = gtk_frame_new ("");
+  label = gtk_frame_get_label_widget (GTK_FRAME (frame_tab));
   gtk_label_set_text_with_mnemonic (GTK_LABEL (label), _("_Tab"));
   gtk_label_set_mnemonic_widget (GTK_LABEL (label), propdlg.spin_tab);
   hbox = gtk_hbox_new (FALSE, SPACING);
@@ -932,10 +934,10 @@ property_dialog (GtkWindow *parent,
   gtk_box_pack_start (GTK_BOX (hbox), propdlg.check_code, FALSE, FALSE, 0);
   gtk_box_pack_start (GTK_BOX (hbox), propdlg.check_uline, FALSE, FALSE, 0);
   gtk_box_pack_start (GTK_BOX (hbox), propdlg.check_vline, FALSE, FALSE, 0);
-  gtk_container_add (GTK_CONTAINER (frame2), hbox);
+  gtk_container_add (GTK_CONTAINER (frame_tab), hbox);
 
-  frame3 = gtk_frame_new ("");
-  label = gtk_frame_get_label_widget (GTK_FRAME (frame3));
+  frame_edit = gtk_frame_new ("");
+  label = gtk_frame_get_label_widget (GTK_FRAME (frame_edit));
   gtk_label_set_text_with_mnemonic (GTK_LABEL (label), _("Ed_it"));
   gtk_label_set_mnemonic_widget (GTK_LABEL (label), propdlg.check_autoindent);
   hbox = gtk_hbox_new (FALSE, SPACING);
@@ -943,10 +945,10 @@ property_dialog (GtkWindow *parent,
   gtk_box_pack_start (GTK_BOX(hbox),
                                     propdlg.check_autoindent, FALSE, FALSE, 0);
   gtk_box_pack_start (GTK_BOX (hbox), propdlg.check_tabconv, FALSE, FALSE, 0);
-  gtk_container_add (GTK_CONTAINER (frame3), hbox);
+  gtk_container_add (GTK_CONTAINER (frame_edit), hbox);
 
-  frame4 = gtk_frame_new ("");
-  label = gtk_frame_get_label_widget (GTK_FRAME (frame4));
+  frame_save = gtk_frame_new ("");
+  label = gtk_frame_get_label_widget (GTK_FRAME (frame_save));
   gtk_label_set_text_with_mnemonic (GTK_LABEL (label), _("_Save"));
   gtk_label_set_mnemonic_widget (GTK_LABEL (label), propdlg.check_eof);
   tbox = gtk_vbox_new (FALSE, SPACING);
@@ -968,10 +970,10 @@ property_dialog (GtkWindow *parent,
   gtk_box_pack_start (GTK_BOX (vbox), propdlg.radio_lower, FALSE, FALSE, 0);
   gtk_box_pack_start (GTK_BOX (hbox), vbox, TRUE, TRUE, 0);
   gtk_box_pack_start (GTK_BOX (tbox), hbox, FALSE, FALSE, 0);
-  gtk_container_add (GTK_CONTAINER (frame4), tbox);
+  gtk_container_add (GTK_CONTAINER (frame_save), tbox);
 
-  frame5 = gtk_frame_new ("");
-  label = gtk_frame_get_label_widget (GTK_FRAME (frame5));
+  frame_color = gtk_frame_new ("");
+  label = gtk_frame_get_label_widget (GTK_FRAME (frame_color));
   gtk_label_set_text_with_mnemonic (GTK_LABEL (label), _("_Color"));
   gtk_label_set_mnemonic_widget (GTK_LABEL (label), propdlg.check_syscol);
   vbox = gtk_vbox_new (FALSE, SPACING);
@@ -981,10 +983,10 @@ property_dialog (GtkWindow *parent,
   hbox = gtk_hbox_new (FALSE, 0);
   gtk_box_pack_end (GTK_BOX (hbox), propdlg.button_color, FALSE, FALSE, 0);
   gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
-  gtk_container_add (GTK_CONTAINER (frame5), vbox);
+  gtk_container_add (GTK_CONTAINER (frame_color), vbox);
 
-  frame6 = gtk_frame_new ("");
-  label = gtk_frame_get_label_widget (GTK_FRAME (frame6));
+  frame_character = gtk_frame_new ("");
+  label = gtk_frame_get_label_widget (GTK_FRAME (frame_character));
   gtk_label_set_text_with_mnemonic (GTK_LABEL (label),
                                                     _("Character _Encoding"));
 #if GTK_CHECK_VERSION(2,4,0)
@@ -996,19 +998,21 @@ property_dialog (GtkWindow *parent,
   vbox = gtk_vbox_new (FALSE, SPACING);
   gtk_container_set_border_width (GTK_CONTAINER (vbox), SPACING);
   gtk_box_pack_start (GTK_BOX (vbox), propdlg.combo, FALSE, FALSE, 0);
-  if (button_auto)
+  if (check_negotiate)
+    gtk_box_pack_start (GTK_BOX (vbox), check_negotiate, FALSE, FALSE, 0);
+  if (button_register)
     {
       hbox = gtk_hbox_new (FALSE, 0);
-      gtk_box_pack_end (GTK_BOX (hbox), button_auto, FALSE, FALSE, 0);
+      gtk_box_pack_start (GTK_BOX (hbox), button_register, FALSE, FALSE, 0);
       gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
     }
   if (propdlg.charset)
     gtk_box_pack_start (GTK_BOX (vbox), propdlg.charset, FALSE, FALSE, 0);
-  if (propdlg.check_html)
-    gtk_box_pack_start (GTK_BOX (vbox), propdlg.check_html, FALSE, FALSE, 0);
-  if (propdlg.check_esc)
-    gtk_box_pack_start (GTK_BOX (vbox), propdlg.check_esc, FALSE, FALSE, 0);
-  gtk_container_add (GTK_CONTAINER (frame6), vbox);
+  if (check_html)
+    gtk_box_pack_start (GTK_BOX (vbox), check_html, FALSE, FALSE, 0);
+  if (check_esc)
+    gtk_box_pack_start (GTK_BOX (vbox), check_esc, FALSE, FALSE, 0);
+  gtk_container_add (GTK_CONTAINER (frame_character), vbox);
 
   tbox = gtk_hbox_new (FALSE, SPACING);
   if (propdlg.entry_text && propdlg.entry_ext)
@@ -1031,15 +1035,15 @@ property_dialog (GtkWindow *parent,
 
   hbox = gtk_hbox_new (FALSE, SPACING);
   vbox = gtk_vbox_new (FALSE, SPACING);
-  gtk_box_pack_start (GTK_BOX (vbox), frame0, FALSE, FALSE, 0);
-  gtk_box_pack_start (GTK_BOX (vbox), frame1, FALSE, FALSE, 0);
-  gtk_box_pack_start (GTK_BOX (vbox), frame2, FALSE, FALSE, 0);
-  gtk_box_pack_start (GTK_BOX (vbox), frame3, FALSE, FALSE, 0);
-  gtk_box_pack_start (GTK_BOX (vbox), frame4, FALSE, FALSE, 0);
+  gtk_box_pack_start (GTK_BOX (vbox), frame_display, FALSE, FALSE, 0);
+  gtk_box_pack_start (GTK_BOX (vbox), frame_right, FALSE, FALSE, 0);
+  gtk_box_pack_start (GTK_BOX (vbox), frame_tab, FALSE, FALSE, 0);
+  gtk_box_pack_start (GTK_BOX (vbox), frame_edit, FALSE, FALSE, 0);
+  gtk_box_pack_start (GTK_BOX (vbox), frame_save, FALSE, FALSE, 0);
   gtk_box_pack_start (GTK_BOX (hbox), vbox, TRUE, TRUE, 0);
   vbox = gtk_vbox_new (FALSE, SPACING);
-  gtk_box_pack_start (GTK_BOX (vbox), frame5, TRUE, TRUE, 0);
-  gtk_box_pack_start (GTK_BOX (vbox), frame6, FALSE, FALSE, 0);
+  gtk_box_pack_start (GTK_BOX (vbox), frame_color, TRUE, TRUE, 0);
+  gtk_box_pack_start (GTK_BOX (vbox), frame_character, FALSE, FALSE, 0);
   gtk_box_pack_start (GTK_BOX (hbox), vbox, TRUE, TRUE, 0);
 
   vbox = gtk_dialog_get_content_area (GTK_DIALOG (propdlg.dialog));
@@ -1054,9 +1058,8 @@ property_dialog (GtkWindow *parent,
 #endif /* not GTK_CHECK_VERSION(2,4,0) */
   if (button_associated)
     gtk_box_pack_start (GTK_BOX (hbox), button_associated, FALSE, FALSE, 0);
-  if (propdlg.check_associate)
-    gtk_box_pack_start (GTK_BOX (hbox),
-                                    propdlg.check_associate, FALSE, FALSE, 0);
+  if (check_associate)
+    gtk_box_pack_start (GTK_BOX (hbox), check_associate, FALSE, FALSE, 0);
   gtk_box_pack_end (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
 
   /* ja:表示 */
@@ -1070,7 +1073,7 @@ property_dialog (GtkWindow *parent,
 
   propdlg.ft_id = ft->ft_id;
   g_memmove (propdlg.gdk_color, ft->color, sizeof (GdkColor) * 12);
-  propdlg.charset_list = button_auto ? g_strdup (ft->charset) : NULL;
+  propdlg.charset_list = button_register ? g_strdup (ft->charset) : NULL;
 #if ! GTK_CHECK_VERSION(2,4,0)
   propdlg.font_name = g_strdup (ft->font_name);
 #endif /* not GTK_CHECK_VERSION(2,4,0) */
@@ -1123,15 +1126,14 @@ property_dialog (GtkWindow *parent,
                                 (GTK_TOGGLE_BUTTON (propdlg.check_overwrite));
       ft->syscol = gtk_toggle_button_get_active
                                 (GTK_TOGGLE_BUTTON (propdlg.check_syscol));
-      if (propdlg.check_html)
+      if (check_html)
         ft->html = gtk_toggle_button_get_active
-                                (GTK_TOGGLE_BUTTON (propdlg.check_html));
-      if (propdlg.check_esc)
-        ft->esc = gtk_toggle_button_get_active
-                                (GTK_TOGGLE_BUTTON (propdlg.check_esc));
-      if (propdlg.check_associate)
+                                (GTK_TOGGLE_BUTTON (check_html));
+      if (check_esc)
+        ft->esc = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (check_esc));
+      if (check_associate)
         ft->associate = gtk_toggle_button_get_active
-                                (GTK_TOGGLE_BUTTON (propdlg.check_associate));
+                                (GTK_TOGGLE_BUTTON (check_associate));
       if (gtk_toggle_button_get_active
                                 (GTK_TOGGLE_BUTTON (propdlg.radio_question)))
         ft->writemode = 1;
@@ -1170,9 +1172,12 @@ property_dialog (GtkWindow *parent,
         }
 #endif /* not GTK_CHECK_VERSION(2,4,0) */
       g_free (ft->charset);
+      if (check_negotiate)
+        ft->negotiate = gtk_toggle_button_get_active
+                                (GTK_TOGGLE_BUTTON (check_negotiate));
       if (propdlg.charset)
         ft->charset = orz_charset_get_charset (ORZ_CHARSET (propdlg.charset));
-      if (button_auto)
+      if (button_register)
         {
           ft->charset = propdlg.charset_list;
           propdlg.charset_list = NULL;
