@@ -1,6 +1,6 @@
 /*
     Text maid
-    copyright (c) 1998-2011 Kazuki Iwamoto http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2012 Kazuki Iwamoto http://www.maid.org/ iwm@maid.org
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -361,18 +361,27 @@ signal_delete_surrounding (GtkIMContext *imcontext,
 
 
 #ifndef G_OS_WIN32
+# if GTK_CHECK_VERSION(3,0,0)
+gboolean
+signal_draw_preedit (GtkWidget   *widget,
+                     cairo_t     *cr,
+                     TmaidWindow *tmaid)
+# else /* not GTK_CHECK_VERSION(3,0,0) */
 gboolean
 signal_expose_preedit (GtkWidget      *widget,
                        GdkEventExpose *event,
                        TmaidWindow    *tmaid)
+# endif /* not GTK_CHECK_VERSION(3,0,0) */
 {
   gchar *str;
-#if GTK_CHECK_VERSION(2,24,0)
+# if ! GTK_CHECK_VERSION(3,0,0)
+#  if GTK_CHECK_VERSION(2,24,0)
   cairo_t *cr;
-#else /* not GTK_CHECK_VERSION(2,24,0) */
+#  else /* not GTK_CHECK_VERSION(2,24,0) */
   GdkGC *gc;
-#endif /* not GTK_CHECK_VERSION(2,24,0) */
+#  endif /* not GTK_CHECK_VERSION(2,24,0) */
   GdkWindow *window;
+# endif /* not GTK_CHECK_VERSION(3,0,0) */
   PangoAttrList *attrs;
 
   gtk_im_context_get_preedit_string (tmaid->im_context, &str, &attrs, NULL);
@@ -381,9 +390,13 @@ signal_expose_preedit (GtkWidget      *widget,
   pango_layout_set_attributes (tmaid->layout, attrs);
   pango_attr_list_unref (attrs);
 
+# if ! GTK_CHECK_VERSION(3,0,0)
   window = gtk_widget_get_window (widget);
-#if GTK_CHECK_VERSION(2,24,0)
+# endif /* not GTK_CHECK_VERSION(3,0,0) */
+# if GTK_CHECK_VERSION(2,24,0)
+#  if ! GTK_CHECK_VERSION(3,0,0)
   cr = gdk_cairo_create (window);
+#  endif /* not GTK_CHECK_VERSION(3,0,0) */
   /* ja:背景 */
   gdk_cairo_set_source_color (cr, (tmaid->ft.syscol
                                         ? system_color : tmaid->ft.color) + 1);
@@ -395,8 +408,10 @@ signal_expose_preedit (GtkWidget      *widget,
                                         ? system_color : tmaid->ft.color);
   cairo_move_to (cr, 0, 0);
   pango_cairo_show_layout (cr, tmaid->layout);
+#  if ! GTK_CHECK_VERSION(3,0,0)
   cairo_destroy (cr);
-#else /* not GTK_CHECK_VERSION(2,24,0) */
+#  endif /* not GTK_CHECK_VERSION(3,0,0) */
+# else /* not GTK_CHECK_VERSION(2,24,0) */
   gc = gdk_gc_new (window);
   /* ja:背景 */
   gdk_gc_set_foreground (gc, (tmaid->ft.syscol
@@ -410,7 +425,7 @@ signal_expose_preedit (GtkWidget      *widget,
                                         ? system_color : tmaid->ft.color) + 1);
   gdk_draw_layout (window, gc, 0, 0, tmaid->layout);
   g_object_unref (gc);
-#endif /* not GTK_CHECK_VERSION(2,24,0) */
+# endif /* not GTK_CHECK_VERSION(2,24,0) */
   pango_layout_set_attributes (tmaid->layout, NULL);
   return TRUE;
 }
@@ -422,27 +437,46 @@ signal_expose_preedit (GtkWidget      *widget,
 * ja:シグナル/イベント関数群(描画)                                            *
 *                                                                             *
 ******************************************************************************/
+#if GTK_CHECK_VERSION(3,0,0)
+gboolean
+signal_draw (GtkWidget   *widget,
+             cairo_t     *cr,
+             TmaidWindow *tmaid)
+#else /* not GTK_CHECK_VERSION(3,0,0) */
 gboolean
 signal_expose (GtkWidget      *widget,
                GdkEventExpose *event,
                TmaidWindow    *tmaid)
+#endif /* not GTK_CHECK_VERSION(3,0,0) */
 {
   gint y;
-
-#if GTK_CHECK_VERSION(2,24,0)
+#if ! GTK_CHECK_VERSION(3,0,0)
+# if GTK_CHECK_VERSION(2,24,0)
   cairo_t *cr;
-#else /* not GTK_CHECK_VERSION(2,24,0) */
+# else /* not GTK_CHECK_VERSION(2,24,0) */
   GdkGC *gc;
-#endif /* not GTK_CHECK_VERSION(2,24,0) */
-  GdkPoint start, end, cursor;
+# endif /* not GTK_CHECK_VERSION(2,24,0) */
   GdkWindow *window;
+#endif /* not GTK_CHECK_VERSION(3,0,0) */
+  GdkPoint start, end, cursor;
+  GdkRectangle area;
   GtkAllocation allocation;
   LineBuffer *p;
 
   gtk_widget_get_allocation (widget, &allocation);
+#if GTK_CHECK_VERSION(3,0,0)
+  area.x = 0;
+  area.y = 0;
+  area.width = allocation.width;
+  area.height = allocation.height;
+#else /* not GTK_CHECK_VERSION(3,0,0) */
+  area = event->area;
   window = gtk_widget_get_window (widget);
+#endif /* not GTK_CHECK_VERSION(3,0,0) */
 #if GTK_CHECK_VERSION(2,24,0)
+# if ! GTK_CHECK_VERSION(3,0,0)
   cr = gdk_cairo_create (window);
+# endif /* not GTK_CHECK_VERSION(3,0,0) */
   cairo_set_line_width (cr, 1);
   cairo_set_line_cap (cr, CAIRO_LINE_CAP_BUTT);
 #else /* not GTK_CHECK_VERSION(2,24,0) */
@@ -477,14 +511,13 @@ signal_expose (GtkWidget      *widget,
 #if GTK_CHECK_VERSION(2,24,0)
   gdk_cairo_set_source_color (cr, (tmaid->ft.syscol
                                         ? system_color : tmaid->ft.color) + 1);
-  cairo_rectangle (cr, event->area.x, event->area.y,
-                                        event->area.width, event->area.height);
+  cairo_rectangle (cr, area.x, area.y, area.width, area.height);
   cairo_fill (cr);
 #else /* not GTK_CHECK_VERSION(2,24,0) */
   gdk_gc_set_foreground (gc, (tmaid->ft.syscol
                                         ? system_color : tmaid->ft.color) + 1);
-  gdk_draw_rectangle (window, gc, TRUE, event->area.x, event->area.y,
-                                        event->area.width, event->area.height);
+  gdk_draw_rectangle (window, gc, TRUE, area.x, area.y,
+                                        area.width, area.height);
 #endif /* not GTK_CHECK_VERSION(2,24,0) */
   if (tmaid->ft.gline)
     {
@@ -497,15 +530,15 @@ signal_expose (GtkWidget      *widget,
       for (x = tmaid->font_width - 1; x < allocation.width;
                                                     x += tmaid->font_width)
         {
-          cairo_move_to (cr, x, event->area.y);
-          cairo_line_to (cr, x, event->area. y + event->area.height);
+          cairo_move_to (cr, x, area.y);
+          cairo_line_to (cr, x, area. y + area.height);
           cairo_stroke (cr);
         }
       for (y = tmaid->font_height - 1; y < allocation.height;
                                                     y += tmaid->font_height)
         {
-          cairo_move_to (cr, event->area.x, y);
-          cairo_line_to (cr, event->area.x + event->area.width, y);
+          cairo_move_to (cr, area.x, y);
+          cairo_line_to (cr, area.x + area.width, y);
           cairo_stroke (cr);
         }
 #else /* not GTK_CHECK_VERSION(2,24,0) */
@@ -513,12 +546,10 @@ signal_expose (GtkWidget      *widget,
                                         ? system_color : tmaid->ft.color) + 7);
       for (x = tmaid->font_width - 1; x < allocation.width;
                                                     x += tmaid->font_width)
-        gdk_draw_line (window, gc,
-                    x, event->area.y, x, event->area. y + event->area.height);
+        gdk_draw_line (window, gc, x, area.y, x, area. y + area.height);
       for (y = tmaid->font_height - 1; y < allocation.height;
                                                     y += tmaid->font_height)
-        gdk_draw_line (window, gc,
-                    event->area.x, y, event->area.x + event->area.width, y);
+        gdk_draw_line (window, gc, area.x, y, area.x + area.width, y);
 #endif /* not GTK_CHECK_VERSION(2,24,0) */
     }
   if (tmaid->ft.vline)
@@ -534,8 +565,8 @@ signal_expose (GtkWidget      *widget,
                                         x < allocation.width;
                                         x += tmaid->font_width * tmaid->ft.tab)
         {
-          cairo_move_to (cr, x, event->area.y);
-          cairo_line_to (cr, x, event->area. y + event->area.height);
+          cairo_move_to (cr, x, area.y);
+          cairo_line_to (cr, x, area. y + area.height);
           cairo_stroke (cr);
         }
 #else /* not GTK_CHECK_VERSION(2,24,0) */
@@ -545,8 +576,7 @@ signal_expose (GtkWidget      *widget,
                                                     * tmaid->font_width - 1;
                                         x < allocation.width;
                                         x += tmaid->font_width * tmaid->ft.tab)
-        gdk_draw_line (window, gc,
-                    x, event->area.y, x, event->area.y + event->area.height);
+        gdk_draw_line (window, gc, x, area.y, x, area.y + area.height);
 #endif /* not GTK_CHECK_VERSION(2,24,0) */
     }
   if (tmaid->ft.mline)
@@ -563,30 +593,29 @@ signal_expose (GtkWidget      *widget,
 #endif /* not GTK_CHECK_VERSION(2,24,0) */
       x = (tmaid->ft.margin - tmaid->top.x) * tmaid->font_width;
 #if GTK_CHECK_VERSION(2,24,0)
-      cairo_move_to (cr, x, event->area.y);
-      cairo_line_to (cr, x, event->area.y + event->area.height);
+      cairo_move_to (cr, x, area.y);
+      cairo_line_to (cr, x, area.y + area.height);
       cairo_stroke (cr);
 #else /* not GTK_CHECK_VERSION(2,24,0) */
-      gdk_draw_line (window, gc,
-                    x, event->area.y, x, event->area.y + event->area.height);
+      gdk_draw_line (window, gc, x, area.y, x, area.y + area.height);
 #endif /* not GTK_CHECK_VERSION(2,24,0) */
     }
 
   for (y = 0, p = edit_get_line_buf (&tmaid->start, &tmaid->off, tmaid->top.y);
-                                y < event->area.y + event->area.height && p;
+                                        y < area.y + area.height && p;
                                         y += tmaid->font_height, p = p->next)
     {
       gint x, data_pos = 0;
 
-      if (y + tmaid->font_height < event->area.y)
+      if (y + tmaid->font_height < area.y)
         continue;
       x = - tmaid->top.x * tmaid->font_width;
-      while (x <= event->area.x + event->area.width && data_pos < p->length)
+      while (x <= area.x + area.width && data_pos < p->length)
         {
           gboolean select;
           gint width;
 
-          if (x + MAX (tmaid->ft.tab, 2) * tmaid->font_width < event->area.x)
+          if (x + MAX (tmaid->ft.tab, 2) * tmaid->font_width < area.x)
             {
               /* ja:左側の表示されない部分を計算する */
               if (p->text[data_pos] == '\t')
@@ -936,11 +965,13 @@ signal_expose (GtkWidget      *widget,
         }
     }
 
-#if GTK_CHECK_VERSION(2,24,0)
+#if ! GTK_CHECK_VERSION(3,0,0)
+# if GTK_CHECK_VERSION(2,24,0)
   cairo_destroy (cr);
-#else /* not GTK_CHECK_VERSION(2,24,0) */
+# else /* not GTK_CHECK_VERSION(2,24,0) */
   g_object_unref (gc);
-#endif /* not GTK_CHECK_VERSION(2,24,0) */
+# endif /* not GTK_CHECK_VERSION(2,24,0) */
+#endif /* not GTK_CHECK_VERSION(3,0,0) */
   return TRUE;
 }
 
