@@ -1,6 +1,6 @@
 /*
     Text maid
-    copyright (c) 1998-2008 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2012 Kazuki Iwamoto http://www.maid.org/ iwm@maid.org
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -71,9 +71,10 @@ signal_value_changed_vscroll (GtkAdjustment *adjust,
                               TmaidWindow   *tmaid);
 
 
-gboolean signal_config (GtkWidget         *widget,
-                        GdkEventConfigure *config,
-                        TmaidWindow       *tmaid);
+gboolean
+signal_config (GtkWidget         *widget,
+               GdkEventConfigure *config,
+               TmaidWindow       *tmaid);
 
 
 void
@@ -112,10 +113,17 @@ signal_delete_surrounding (GtkIMContext *imcontext,
 
 
 #ifndef G_OS_WIN32
+# if GTK_CHECK_VERSION(3,0,0)
+gboolean
+signal_draw_preedit (GtkWidget   *widget,
+                     cairo_t     *cr,
+                     TmaidWindow *tmaid);
+# else /* not GTK_CHECK_VERSION(3,0,0) */
 gboolean
 signal_expose_preedit (GtkWidget      *widget,
                        GdkEventExpose *event,
                        TmaidWindow    *tmaid);
+# endif /* not GTK_CHECK_VERSION(3,0,0) */
 #endif /* not G_OS_WIN32 */
 
 
@@ -124,10 +132,17 @@ signal_expose_preedit (GtkWidget      *widget,
 * ja:シグナル/イベント関数群(描画)                                            *
 *                                                                             *
 ******************************************************************************/
+#if GTK_CHECK_VERSION(3,0,0)
+gboolean
+signal_draw (GtkWidget   *widget,
+             cairo_t     *cr,
+             TmaidWindow *tmaid);
+#else /* not GTK_CHECK_VERSION(3,0,0) */
 gboolean
 signal_expose (GtkWidget      *widget,
                GdkEventExpose *event,
                TmaidWindow    *tmaid);
+#endif /* not GTK_CHECK_VERSION(3,0,0) */
 
 
 /******************************************************************************
