@@ -1,6 +1,6 @@
 /*
     Text maid
-    copyright (c) 1998-2008 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2011 Kazuki Iwamoto http://www.maid.org/ iwm@maid.org
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -23,7 +23,6 @@
 #include "sigkey.h"
 #include "misc/misc.h"
 #include "orz/orzmdi.h"
-#include <gdk/gdkkeysyms.h>
 
 
 /******************************************************************************
@@ -42,64 +41,66 @@ signal_key_press (GtkWidget   *widget,
     return TRUE;
   switch (event->keyval)
     {
-      case GDK_Home:
-      case GDK_KP_Home:
-      case GDK_End:
-      case GDK_KP_End:
-      case GDK_H:
-      case GDK_h:
-      case GDK_Left:
-      case GDK_KP_Left:
-      case GDK_L:
-      case GDK_l:
-      case GDK_Right:
-      case GDK_KP_Right:
-      case GDK_comma:
-      case GDK_less:
-      case GDK_period:
-      case GDK_greater:
-      case GDK_K:
-      case GDK_k:
-      case GDK_Up:
-      case GDK_KP_Up:
-      case GDK_J:
-      case GDK_j:
-      case GDK_Down:
-      case GDK_KP_Down:
-      case GDK_Page_Up:
-      case GDK_KP_Page_Up:
-      case GDK_Page_Down:
-      case GDK_KP_Page_Down:
+      case GDK_KEY_Home:
+      case GDK_KEY_KP_Home:
+      case GDK_KEY_End:
+      case GDK_KEY_KP_End:
+      case GDK_KEY_H:
+      case GDK_KEY_h:
+      case GDK_KEY_Left:
+      case GDK_KEY_KP_Left:
+      case GDK_KEY_L:
+      case GDK_KEY_l:
+      case GDK_KEY_Right:
+      case GDK_KEY_KP_Right:
+      case GDK_KEY_comma:
+      case GDK_KEY_less:
+      case GDK_KEY_period:
+      case GDK_KEY_greater:
+      case GDK_KEY_K:
+      case GDK_KEY_k:
+      case GDK_KEY_Up:
+      case GDK_KEY_KP_Up:
+      case GDK_KEY_J:
+      case GDK_KEY_j:
+      case GDK_KEY_Down:
+      case GDK_KEY_KP_Down:
+      case GDK_KEY_Page_Up:
+      case GDK_KEY_KP_Page_Up:
+      case GDK_KEY_Page_Down:
+      case GDK_KEY_KP_Page_Down:
         {
           gint max, sx, sy, width;
           gboolean alt, ctrl;
           GdkPoint cursor, top, select;
+          GtkAllocation allocation;
 
           cursor = tmaid->cursor;
           top = tmaid->top;
-          sx = MAX (tmaid->drawing->allocation.width / tmaid->font_width, 1);
-          sy = MAX (tmaid->drawing->allocation.height / tmaid->font_height, 1);
+          gtk_widget_get_allocation (tmaid->drawing, &allocation);
+          sx = MAX (allocation.width / tmaid->font_width, 1);
+          sy = MAX (allocation.height / tmaid->font_height, 1);
           alt = event->state & GDK_MOD1_MASK;
           ctrl = event->state & GDK_CONTROL_MASK;
           switch (event->keyval)
             {
-              case GDK_Home:
-              case GDK_KP_Home:
+              case GDK_KEY_Home:
+              case GDK_KEY_KP_Home:
                 tmaid->cursor.x = 0;
                 if (ctrl)
                   tmaid->cursor.y = 0;
                 break;
-              case GDK_End:
-              case GDK_KP_End:
+              case GDK_KEY_End:
+              case GDK_KEY_KP_End:
                 tmaid->cursor.x = edit_get_width (tmaid,
                     ctrl ? tmaid->cursor.y = tmaid->max - 1 : tmaid->cursor.y);
                 break;
-              case GDK_H:
-              case GDK_h:
+              case GDK_KEY_H:
+              case GDK_KEY_h:
                 if (!alt)
                   return result;
-              case GDK_Left:
-              case GDK_KP_Left:
+              case GDK_KEY_Left:
+              case GDK_KEY_KP_Left:
                 tmaid->cursor.x = edit_get_align_pos (tmaid,
                                     tmaid->cursor.x, tmaid->cursor.y, FALSE);
                 if (tmaid->cursor.x > 0)
@@ -116,12 +117,12 @@ signal_key_press (GtkWidget   *widget,
                     tmaid->cursor.x = edit_get_width (tmaid, tmaid->cursor.y);
                   }
                 break;
-              case GDK_L:
-              case GDK_l:
+              case GDK_KEY_L:
+              case GDK_KEY_l:
                 if (!alt)
                   return result;
-              case GDK_Right:
-              case GDK_KP_Right:
+              case GDK_KEY_Right:
+              case GDK_KEY_KP_Right:
                 width = edit_get_width (tmaid, tmaid->cursor.y);
                 if (tmaid->cursor.x < width)
                   {
@@ -137,8 +138,8 @@ signal_key_press (GtkWidget   *widget,
                     tmaid->cursor.y++;
                   }
                 break;
-              case GDK_comma:
-              case GDK_less:
+              case GDK_KEY_comma:
+              case GDK_KEY_less:
                 if (!ctrl)
                   return result;
                 tmaid->cursor.x = edit_get_align_pos (tmaid,
@@ -155,8 +156,8 @@ signal_key_press (GtkWidget   *widget,
                     tmaid->cursor.x = edit_get_width (tmaid, tmaid->cursor.y);
                   }
                 break;
-              case GDK_period:
-              case GDK_greater:
+              case GDK_KEY_period:
+              case GDK_KEY_greater:
                 if (!ctrl)
                   return result;
                 width = edit_get_width (tmaid, tmaid->cursor.y);
@@ -172,12 +173,12 @@ signal_key_press (GtkWidget   *widget,
                     tmaid->cursor.y++;
                   }
                 break;
-              case GDK_K:
-              case GDK_k:
+              case GDK_KEY_K:
+              case GDK_KEY_k:
                 if (!alt)
                   return result;
-              case GDK_Up:
-              case GDK_KP_Up:
+              case GDK_KEY_Up:
+              case GDK_KEY_KP_Up:
                 if (!ctrl)
                   {
                     tmaid->cursor.y--;
@@ -189,12 +190,12 @@ signal_key_press (GtkWidget   *widget,
                       tmaid->cursor.y--;
                   }
                 break;
-              case GDK_J:
-              case GDK_j:
+              case GDK_KEY_J:
+              case GDK_KEY_j:
                 if (!alt)
                   return result;
-              case GDK_Down:
-              case GDK_KP_Down:
+              case GDK_KEY_Down:
+              case GDK_KEY_KP_Down:
                 if (!ctrl)
                   {
                     tmaid->cursor.y++;
@@ -206,8 +207,8 @@ signal_key_press (GtkWidget   *widget,
                       tmaid->cursor.y++;
                   }
                 break;
-              case GDK_Page_Up:
-              case GDK_KP_Page_Up:
+              case GDK_KEY_Page_Up:
+              case GDK_KEY_KP_Page_Up:
                 if (ctrl)
                   {
                     tmaid->cursor.y = tmaid->top.y;
@@ -218,8 +219,8 @@ signal_key_press (GtkWidget   *widget,
                     tmaid->top.y -= sy;
                   }
                 break;
-              case GDK_Page_Down:
-              case GDK_KP_Page_Down:
+              case GDK_KEY_Page_Down:
+              case GDK_KEY_KP_Page_Down:
                 if (ctrl)
                   {
                     tmaid->cursor.y = tmaid->top.y + sy - 1;
@@ -281,9 +282,8 @@ signal_key_press (GtkWidget   *widget,
             misc_set_scroll_bar (tmaid->vscroll,
                         G_CALLBACK (signal_value_changed_vscroll), tmaid,
                         0, tmaid->max, sy, tmaid->top.y);
-          if (tmaid->top.x != top.x
-                || gtk_range_get_adjustment (GTK_RANGE (tmaid->hscroll))->upper
-                                                                        != max)
+          if (tmaid->top.x != top.x || gtk_adjustment_get_upper
+                (gtk_range_get_adjustment (GTK_RANGE (tmaid->hscroll))) != max)
             misc_set_scroll_bar (tmaid->hscroll,
                             G_CALLBACK (signal_value_changed_hscroll), tmaid,
                                                 0, max + 1, sx, tmaid->top.x);
@@ -295,7 +295,7 @@ signal_key_press (GtkWidget   *widget,
         }
         result = TRUE;
         break;
-      case GDK_BackSpace:
+      case GDK_KEY_BackSpace:
         {
           TmaidHistory *d;
           GdkPoint select;
@@ -335,10 +335,10 @@ signal_key_press (GtkWidget   *widget,
         }
         result = TRUE;
         break;
-      case GDK_Return:
-      case GDK_KP_Enter:
-      case GDK_ISO_Enter:
-      case GDK_3270_Enter:
+      case GDK_KEY_Return:
+      case GDK_KEY_KP_Enter:
+      case GDK_KEY_ISO_Enter:
+      case GDK_KEY_3270_Enter:
         {
           gchar *text;
           gint i, data_pos;
@@ -375,8 +375,8 @@ signal_key_press (GtkWidget   *widget,
         }
         result = TRUE;
         break;
-      case GDK_Tab:
-      case GDK_KP_Tab:
+      case GDK_KEY_Tab:
+      case GDK_KEY_KP_Tab:
         {
           gchar *text;
           gint n, align_pos;
@@ -431,18 +431,20 @@ signal_key_press (GtkWidget   *widget,
         }
         result = TRUE;
         break;
-      case GDK_Escape:
-      case GDK_Cancel:
+      case GDK_KEY_Escape:
+      case GDK_KEY_Cancel:
         {
           gint sx, sy;
           GdkPoint select, top;
+          GtkAllocation allocation;
 
           if (tmaid->select.x < 0)
             break;
           select = tmaid->select;
           top = tmaid->top;
-          sx = MAX (tmaid->drawing->allocation.width / tmaid->font_width, 1);
-          sy = MAX (tmaid->drawing->allocation.height / tmaid->font_height, 1);
+          gtk_widget_get_allocation (tmaid->drawing, &allocation);
+          sx = MAX (allocation.width / tmaid->font_width, 1);
+          sy = MAX (allocation.height / tmaid->font_height, 1);
           if (tmaid->cursor.x < tmaid->top.x)
             tmaid->top.x = tmaid->cursor.x;
           else if (tmaid->cursor.x - sx + 1 > tmaid->top.x)
@@ -467,9 +469,9 @@ signal_key_press (GtkWidget   *widget,
         }
         result = TRUE;
         break;
-      case GDK_Delete:
-      case GDK_KP_Delete:
-      case GDK_3270_DeleteWord:
+      case GDK_KEY_Delete:
+      case GDK_KEY_KP_Delete:
+      case GDK_KEY_3270_DeleteWord:
         {
           gint width;
           TmaidHistory *d;
@@ -511,14 +513,14 @@ signal_key_press (GtkWidget   *widget,
         }
         result = TRUE;
         break;
-      case GDK_Insert:
-      case GDK_KP_Insert:
+      case GDK_KEY_Insert:
+      case GDK_KEY_KP_Insert:
         ins = !ins;
         draw_caret (tmaid, NULL);
         result = TRUE;
         break;
-      case GDK_Y:
-      case GDK_y:
+      case GDK_KEY_Y:
+      case GDK_KEY_y:
         {
           TmaidHistory *d;
           GdkPoint select;
@@ -557,22 +559,24 @@ signal_key_press (GtkWidget   *widget,
             tmaid->undo = d;
             if (delete_list(&tmaid->redo) > 0 || !d->next || select.x >= 0)
               set_menu_bar (tmaid);
-              orz_mdi_set_edited (ORZ_MDI (mdi),
+            orz_mdi_set_edited (ORZ_MDI (mdi),
                     orz_mdi_get_page_from_data (ORZ_MDI (mdi), tmaid), TRUE);
         }
         result = TRUE;
         break;
-      case GDK_F10:
+      case GDK_KEY_F10:
         {
           gint sx, sy;
           GdkPoint top;
+          GtkAllocation allocation;
           GtkWidget *menu_shell, *menu_item;
 
           if (!(event->state & GDK_SHIFT_MASK))
             break;
           top = tmaid->top;
-          sx = MAX (tmaid->drawing->allocation.width / tmaid->font_width, 1);
-          sy = MAX (tmaid->drawing->allocation.height / tmaid->font_height, 1);
+          gtk_widget_get_allocation (tmaid->drawing, &allocation);
+          sx = MAX (allocation.width / tmaid->font_width, 1);
+          sy = MAX (allocation.height / tmaid->font_height, 1);
           if (tmaid->cursor.x < tmaid->top.x)
             tmaid->top.x = tmaid->cursor.x;
           else if (tmaid->cursor.x - sx + 1 > tmaid->top.x)
@@ -592,7 +596,11 @@ signal_key_press (GtkWidget   *widget,
                         0, tmaid->max, sy, tmaid->top.y);
 
           menu_item = misc_find_menu (popup_entries, "/input");
+#if GTK_CHECK_VERSION(2,12,0)
+          gtk_menu_item_set_submenu (GTK_MENU_ITEM (menu_item), NULL);
+#else /* not GTK_CHECK_VERSION(2,12,0) */
           gtk_menu_item_remove_submenu (GTK_MENU_ITEM (menu_item));
+#endif /* not GTK_CHECK_VERSION(2,12,0) */
           menu_shell = gtk_menu_new ();
           gtk_im_multicontext_append_menuitems (GTK_IM_MULTICONTEXT
                             (tmaid->im_context), GTK_MENU_SHELL (menu_shell));
