@@ -1,6 +1,6 @@
 /*
     Text maid
-    copyright (c) 1998-2012 Kazuki Iwamoto http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2013 Kazuki Iwamoto http://www.maid.org/ iwm@maid.org
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -19,23 +19,24 @@
 #define __TMAID_H__
 
 
-#include "misc/gcommon.h"
+#include "gcommon/gcommon.h"
 
 
 G_BEGIN_DECLS
 
 
 #define TMAID_VERSION_NOTICE "Text maid "VERSION" ("BUILD_ENVIRONMENT")"
-#define TMAID_COPYRIGHT_NOTICE "Copyright (C) 1998-2012 Kazuki Iwamoto"
+#define TMAID_COPYRIGHT_NOTICE "Copyright (C) 1998-2013 Kazuki Iwamoto"
 
 
 typedef struct _FileType
 {
   gint ft_id;               /* ja:ファイルタイプのID(-1:無所属) */
-  gint crlf;                /* ja:0:CR+LF,1:CR,2:LF,3:自動 */
+  gint crlf;                /* ja:0:CR+LF,1:CR,2:LF */
   gint margin;              /* ja:右マージンの数 */
   gint tab;                 /* ja:タブの数 */
   gint writemode;           /* ja:0:Abort,1:'?',2:HTML,3:Escape */
+  gboolean negotiate;       /* ja:TRUE:CRLF自動判別 */
   gboolean autoindent;      /* ja:TRUE:自動字下げ */
   gboolean associate;       /* ja:TRUE:関連づける */
   gboolean code;            /* ja:TRUE:タブのコードを表示する */
